==> kports-0.8.1.tar.bz2: kports-0.8.1/src/portstreemodel.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Hannes Hauswedell                          *
 *   kports@soulrebel.in-berlin.de                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#ifndef PORTSTREEMODEL_H
#define PORTSTREEMODEL_H

#include <QStandardItemModel>
#include <QStandardItem>
#include <QSortFilterProxyModel>
#include <QTimer>
#include <QString>
#include <QStringList>
#include <QMetaType>

#include "bsdport.h"
#include "kportsicons.h"

class QBsdPort;
class QPortMetaItem;


/**
	@author Hannes Hauswedell <kports@soulrebel.in-berlin.de>
*/
class QPortsTreeModel : public QStandardItemModel
{
Q_OBJECT
private:
    QList <QPortMetaItem*> list;
    int    m_currentSearchId;
public:
    QPortsTreeModel(QObject *parent);

    ~QPortsTreeModel();

    int currentSearchId()   const { return m_currentSearchId; }
public slots:
    void addPortToModel(QBsdPort*);
    void searchResultReceived(QBsdPort*);

    // 1 central
    void portStateReceived(QBsdPort* p, const QString& inst,
                                  const QString& avsrc, const QString& avbin);

    void    incSearchId()
    {
        ++m_currentSearchId;
    }
};

/** A Meta-Item for every Row **/
class QPortMetaItem : public QObject
{
// Q_OBJECT
private:

    QStandardItem*  m_col0;
    QStandardItem*  m_col1;
    QStandardItem*  m_col2;
    QList <QStandardItem*> m_cols;
    QBsdPort*   m_port;

public:
    QPortMetaItem(QBsdPort* p)
        : QObject()
    {
        m_port = p;
        m_col0 = new QStandardItem(
                                KPortsIcons::iconLoader.loadIcon(
                                "application-x-compressed-tar"),
                                m_port->origin().section('/', -1, -1) );
        m_col1 = new QStandardItem();
        m_col2 = new QStandardItem();
        m_cols << m_col0 << m_col1 << m_col2;

        /// TODO save pointer instead
        /// save origin in items
        m_col0->setData(m_port->origin(), 50);
        m_col1->setData(m_port->origin(), 50);
        m_col2->setData(m_port->origin(), 50);

        /// initialize as NOT-A-SEARCHRESULT
        m_col0->setData(-1, 51);
// 3 original single
//         connect(m_port, SIGNAL(instState(const QString&)),
//                 this, SLOT(updateInst(const QString&)));
//         connect(m_port, SIGNAL(avSrcState(const QString&)),
//                 this, SLOT(updateAvSrc(const QString&)));
//         connect(m_port, SIGNAL(avBinState(const QString&)),
//                 this, SLOT(updateAvBin(const QString&)));
// 
// 
//         QMetaObject::invokeMethod(port(),
//                                   "emitAvSrcState",
//                                   Qt::QueuedConnection );

//-

// 2 new single
/*		connect(port(),	SIGNAL(pkgState(const QString&,
                                              const QString&, const QString&)),
				this,	SLOT(pkgStateReceived(const QString&,
                                            const QString&, const QString&)));
        QMetaObject::invokeMethod(port(),
                                  "emitPkgState",
                                  Qt::QueuedConnection );*/
//-
    }

    ~QPortMetaItem()
    {
        delete m_col0;
        delete m_col1;
        delete m_col2;
    }

    QStandardItem*  col0()    const { return m_col0; }
    QStandardItem*  col1()    const { return m_col1; }
    QStandardItem*  col2()    const { return m_col2; }
    QList <QStandardItem*>  cols()    const { return m_cols; }
    QBsdPort*       port()    const { return m_port; }
/*
public slots:
// 2 new single
    void pkgStateReceived(const QString& inst,
                          const QString& avsrc, const QString& avbin);

// 3 original single
private slots:
    inline void updateInst(const QString& newValue)
    {
        m_col1->setData(newValue.section('-',-1,-1),0);
    }
    inline void updateAvSrc(const QString& newValue)
    {
        m_col2->setData(newValue.section('-',-1,-1),33);
        if (m_col2->data(33).toString() > m_col2->data(34).toString())
            m_col2->setData(newValue.section('-',-1,-1),0);


    }
    inline void updateAvBin(const QString& newValue)
    {
        m_col2->setData(newValue.section('-',-1,-1),34);
        if (m_col2->data(34).toString() > m_col2->data(33).toString())
            m_col2->setData(newValue.section('-',-1,-1),0);

    }
//-*/
};

class QBrowseViewFilterModel : public QSortFilterProxyModel
{
Q_OBJECT
private:
    bool    m_installed;
    bool    m_vulnerable;
    bool    m_upgradeable;

    /* the timer buffers invalidate-requests to prevent needles filterings */
    QTimer  *setRegExpTimer;
    QString m_myFilterRegExp;
public:
    QBrowseViewFilterModel(QObject *parent = 0)
        : QSortFilterProxyModel(parent)
    {
        setInstalled(false);
        setVulnerable(false);
        setUpgradeable(false);

        setRegExpTimer = new QTimer(this);
        setRegExpTimer->setSingleShot(true);
        setRegExpTimer->setInterval(800);
        connect(setRegExpTimer, SIGNAL(timeout()),
                this,           SLOT(mySetRegExp()));

        setSortCaseSensitivity(Qt::CaseInsensitive);
        setDynamicSortFilter(true);
    }

    ~QBrowseViewFilterModel()
    {
        delete setRegExpTimer;
    }

    bool    installed()     const { return m_installed; }
    bool    vulnerable()    const { return m_vulnerable; }
    bool    upgradeable()   const { return m_upgradeable; }

    bool    filterAcceptsRow(int, const QModelIndex&) const;

public slots:
    void    setInstalled(bool newValue)     { m_installed = newValue; }
    void    setVulnerable(bool newValue)    { m_vulnerable = newValue; }
    void    setUpgradeable(bool newValue)   { m_upgradeable = newValue; }

    void    delayedSetFilterRegExp(const QString& newValue)
    {
        m_myFilterRegExp = newValue;
        setRegExpTimer->start();
    }

    void    mySetRegExp()
    {
        setFilterRegExp(m_myFilterRegExp);
    }

};

class QSearchViewFilterModel : public QSortFilterProxyModel
{
Q_OBJECT
private:

public:
    QSearchViewFilterModel(QObject *parent = 0);


    bool    filterAcceptsRow(int, const QModelIndex&) const;

};
#endif

==> kports-0.8.2.tar.bz2: kports-0.8.2/src/portstreemodel.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Hannes Hauswedell                          *
 *   kports@soulrebel.in-berlin.de                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#ifndef PORTSTREEMODEL_H
#define PORTSTREEMODEL_H

#include <QStandardItemModel>
#include <QStandardItem>
#include <QSortFilterProxyModel>
#include <QTimer>
#include <QString>
#include <QStringList>
#include <QMetaType>
#include <QThread>

#include "bsdport.h"
#include "kportsicons.h"

class QBsdPort;
class QPortMetaItem;


/**
	@author Hannes Hauswedell <kports@soulrebel.in-berlin.de>
*/
class QPortsTreeModel : public QStandardItemModel
{
Q_OBJECT
private:
    QMap<QBsdPort*, QPortMetaItem*> map;
    int    m_currentSearchId;
public:
    QPortsTreeModel(QObject *parent);

    ~QPortsTreeModel();

    int currentSearchId()   const { return m_currentSearchId; }
public slots:
    void addPortToModel(QBsdPort*);
    void searchResultReceived(QBsdPort*);

    // 1 central
    void reset();
    void portStateReceived(QBsdPort* p, const QString& inst,
                                  const QString& avsrc, const QString& avbin);

    void    incSearchId()
    {
        ++m_currentSearchId;
    }
signals:
    void wasReset();
};

/** A Meta-Item for every Row **/
class QPortMetaItem : public QObject
{
// Q_OBJECT
private:

    QStandardItem*  m_col0;
    QStandardItem*  m_col1;
    QStandardItem*  m_col2;
    QList <QStandardItem*> m_cols;
    QBsdPort*   m_port;

public:
    QPortMetaItem(QBsdPort* p, QObject *parent = 0)
        : QObject(parent)
    {
        m_port = p;
        m_col0 = new QStandardItem(
                                KPortsIcons::iconLoader.loadIcon(
                                "application-x-compressed-tar"),
                                m_port->origin().section('/', -1, -1) );
//        m_col0->setParent(this);
        m_col1 = new QStandardItem();
//        m_col1->setParent(this);
        m_col2 = new QStandardItem();
//        m_col0->setParent(this);
        m_cols << m_col0 << m_col1 << m_col2;

        /// TODO save pointer instead
        /// save origin in items
        m_col0->setData(m_port->origin(), 50);
        m_col1->setData(m_port->origin(), 50);
        m_col2->setData(m_port->origin(), 50);

        /// initialize as NOT-A-SEARCHRESULT
        m_col0->setData(-1, 51);

        connect(m_port,     SIGNAL(destroyed(QObject*)),
                this,       SLOT(deleteLater()));
        
// 3 original single
//         connect(m_port, SIGNAL(instState(const QString&)),
//                 this, SLOT(updateInst(const QString&)));
//         connect(m_port, SIGNAL(avSrcState(const QString&)),
//                 this, SLOT(updateAvSrc(const QString&)));
//         connect(m_port, SIGNAL(avBinState(const QString&)),
//                 this, SLOT(updateAvBin(const QString&)));
// 
// 
//         QMetaObject::invokeMethod(port(),
//                                   "emitAvSrcState",
//                                   Qt::QueuedConnection );

//-

// 2 new single
/*		connect(port(),	SIGNAL(pkgState(const QString&,
                                              const QString&, const QString&)),
				this,	SLOT(pkgStateReceived(const QString&,
                                            const QString&, const QString&)));
        QMetaObject::invokeMethod(port(),
                                  "emitPkgState",
                                  Qt::QueuedConnection );*/
//-
    }

    ~QPortMetaItem()
    {
        delete m_col0;
        delete m_col1;
        delete m_col2;
    }

    QStandardItem*  col0()    const { return m_col0; }
    QStandardItem*  col1()    const { return m_col1; }
    QStandardItem*  col2()    const { return m_col2; }
    QList <QStandardItem*>  cols()    const { return m_cols; }
    QBsdPort*       port()    const { return m_port; }
/*
public slots:
// 2 new single
    void pkgStateReceived(const QString& inst,
                          const QString& avsrc, const QString& avbin);

// 3 original single
private slots:
    inline void updateInst(const QString& newValue)
    {
        m_col1->setData(newValue.section('-',-1,-1),0);
    }
    inline void updateAvSrc(const QString& newValue)
    {
        m_col2->setData(newValue.section('-',-1,-1),33);
        if (m_col2->data(33).toString() > m_col2->data(34).toString())
            m_col2->setData(newValue.section('-',-1,-1),0);


    }
    inline void updateAvBin(const QString& newValue)
    {
        m_col2->setData(newValue.section('-',-1,-1),34);
        if (m_col2->data(34).toString() > m_col2->data(33).toString())
            m_col2->setData(newValue.section('-',-1,-1),0);

    }
//-*/
};

class QBrowseViewFilterModel : public QSortFilterProxyModel
{
Q_OBJECT
private:
    bool    m_installed;
    bool    m_vulnerable;
    bool    m_upgradeable;

    /* the timer buffers invalidate-requests to prevent needles filterings */
    QTimer  *setRegExpTimer;
    QString m_myFilterRegExp;
public:
    QBrowseViewFilterModel(QObject *parent = 0)
        : QSortFilterProxyModel(parent)
    {
        setInstalled(false);
        setVulnerable(false);
        setUpgradeable(false);

        setRegExpTimer = new QTimer(this);
        setRegExpTimer->setSingleShot(true);
        setRegExpTimer->setInterval(800);
        connect(setRegExpTimer, SIGNAL(timeout()),
                this,           SLOT(mySetRegExp()));

        setSortCaseSensitivity(Qt::CaseInsensitive);
        setDynamicSortFilter(true);
    }

    ~QBrowseViewFilterModel()
    {
        delete setRegExpTimer;
    }

    bool    installed()     const { return m_installed; }
    bool    vulnerable()    const { return m_vulnerable; }
    bool    upgradeable()   const { return m_upgradeable; }

    bool    filterAcceptsRow(int, const QModelIndex&) const;

public slots:
    void    setInstalled(bool newValue)     { m_installed = newValue; }
    void    setVulnerable(bool newValue)    { m_vulnerable = newValue; }
    void    setUpgradeable(bool newValue)   { m_upgradeable = newValue; }

    void    delayedSetFilterRegExp(const QString& newValue)
    {
        m_myFilterRegExp = newValue;
        setRegExpTimer->start();
    }

    void    mySetRegExp()
    {
        setFilterRegExp(m_myFilterRegExp);
    }

};

class QSearchViewFilterModel : public QSortFilterProxyModel
{
Q_OBJECT
private:

public:
    QSearchViewFilterModel(QObject *parent = 0);


    bool    filterAcceptsRow(int, const QModelIndex&) const;

};
#endif
